@@ -1,5 +1,7 @@
-# file for rich printing
-
+"""
+Name: help_text
+Desc: the help text for smol-k8s-lab
+"""
 import click
 from rich.console import Console
 from rich.highlighter import RegexHighlighter
@@ -8,7 +10,7 @@ from rich.table import Table
 from rich.text import Text
 from rich.theme import Theme
 
-from .env_config import VERSION
+from .env_config import VERSION, XDG_CONFIG_DIR
 
 
 def pretty_choices(default_list):
@@ -34,9 +36,8 @@ def options_help():
         'Install Argo CD as part of this script. Default: False',
 
         'config':
-        'Full path and name of yml to parse. '
-        'Default: ~/.config/smol-k8s-lab/config.yaml\n'
-        'Example: smol-k8s-lab -f [light_steel_blue]/tmp/config.yaml[/]',
+        'Full path and name of yml to parse.\n Defaults to '
+        f'[light_steel_blue]{XDG_CONFIG_DIR}[/]',
 
         'delete':
         'Delete the existing cluster.',
@@ -63,7 +64,7 @@ def options_help():
         'your vault password. Default: False',
 
         'version':
-        f'Print the installed version of the smol-k8s-lab (v{VERSION})'
+        f'Print the version of smol-k8s-lab (v{VERSION})'
         }
 
 
@@ -89,7 +90,7 @@ class RichCommand(click.Command):
                                        "switch": "sky_blue2",
                                        "meta": "light_steel_blue",
                                        "skl_title": "cornflower_blue"}),
-                          highlighter=highlighter)
+                          highlighter=highlighter, record=False)
 
         title = "☁️  [cornflower_blue][i]smol k8s lab[/] 🧸\n"
         desc = ("[steel_blue]Quickly install a k8s distro for a lab setup."
@@ -100,7 +101,7 @@ class RichCommand(click.Command):
         console.print(title + desc, justify="center")
 
         console.print("[steel_blue]Usage:[/] smol-k8s-lab "
-                      "[meta]<k3s OR kind>[meta/] [option][OPTIONS]\n")
+                      "[meta]<k0s, k3s, kind>[meta/] [option][OPTIONS]\n")
 
         options_table = Table(highlight=True, box=None, show_header=False,
                               row_styles=["dim", ""],
@@ -130,6 +131,10 @@ class RichCommand(click.Command):
             if param.metavar:
                 options += f" {param.metavar}"
 
+            if "help" in opt1:
+                opt1 = "-h"
+                opt2 = "--help"
+
             options_table.add_row(opt1, opt2, highlighter(help))
 
         url = ("♥ [link=https://jessebot.github.io/smol-k8s-lab]"
